@@ -5,7 +5,6 @@
  * kmp_itt.cpp -- ITT Notify interface.
  */
 
-
 //===----------------------------------------------------------------------===//
 //
 //                     The LLVM Compiler Infrastructure
@@ -15,7 +14,6 @@
 //
 //===----------------------------------------------------------------------===//
 
-
 #include "kmp_itt.h"
 
 #if KMP_DEBUG
@@ -70,7 +68,7 @@ void __kmp_itt_initialize() {
                       __kmp_version_minor, __kmp_version_build);
   if (__itt_api_version_ptr != NULL) {
     __kmp_str_buf_print(&buf, ":%s", __itt_api_version());
-  }; // if
+  }
   version = __itt_mark_create(buf.str);
   __itt_mark(version, NULL);
   __kmp_str_buf_free(&buf);
@@ -144,8 +142,8 @@ extern "C" void __itt_error_handler(__itt_error_code err, va_list args) {
       __kmp_str_free(&err_code.str);
     }
   } break;
-  default: { KMP_WARNING(IttUnknownError, err); };
-  }; // switch
+  default: { KMP_WARNING(IttUnknownError, err); }
+  }
 } // __itt_error_handler
 
 #endif /* USE_ITT_BUILD */
